@@ -14,6 +14,7 @@
 
 #ifndef _Included_org_gnu_gtk_EntryCompletion
 #define _Included_org_gnu_gtk_EntryCompletion
+#include "org_gnu_gtk_EntryCompletion.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -233,7 +234,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_EntryCompletion_gtk_1entry_1completion_1
 /*
  * Class:     org_gnu_gtk_EntryCompletion
  * Method:    gtk_entry_completion_get_popup_set_width
- * Signature: (Lorg/gnu/javagnome/Handle;)Z
+ * Signature: (Lorg/gnu/glib/Handle;)Z
  */
 JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_EntryCompletion_gtk_1entry_1completion_1get_1popup_1set_1width
   (JNIEnv *env, jclass cls, jobject entry)
